﻿Option Explicit On
' Preferences dialog for the Digital Clock
' Tom Burt - 07-24-2013 - Initial Code
Public Class FormDClockOptions

    Dim amActive As Boolean = False
    Dim curTime As Date, iTicks As Integer = 0

    Dim T_Properties As ClockProperties
    Dim aFont As Font

    Sub PostTime()
        Dim tDate As String, tTime As String
        curTime = Now
        tDate = Format(curTime, "MMMM dd, yyyy")
        If T_Properties.C_Mode = 0 Then
            ' 12 hour mode
            If T_Properties.C_Seconds Then
                ' Show hours, minutes and seconds AM/PM
                tTime = Format(curTime, "hh:mm:ss tt")
            Else
                ' Show hours, minutes AM/PM
                tTime = Format(curTime, "hh:mm tt")
            End If
        Else
            ' 24 hour mode
            If T_Properties.C_Seconds Then
                ' Show hours, minutes and seconds
                tTime = Format(curTime, "HH:mm:ss")
            Else
                ' Show hours, minutes
                tTime = Format(curTime, "HH:mm")
            End If
        End If
        txtClock.Text = tTime
        iTicks = 0

    End Sub

    ' Save the various settings
    Sub DoSaveSettings()
        ' Copy the working settings back to the master settings struct
        C_Properties = T_Properties

        ' Save those settings
        SaveClockProperties()

    End Sub

    ' Set the properties of the Preview Clock based on the current settings
    Sub SetClockProperties()
        If amActive Then
            txtClock.ForeColor = T_Properties.C_ForeColor
            txtClock.BackColor = T_Properties.C_Backcolor
            txtClock.Font = aFont
        End If
    End Sub

    ' Set up the screen widgets to reflect the current settings
    ' Also sets up a Font object for the current font
    Sub SetupScreen()

        chkSeconds.Checked = T_Properties.C_Seconds
        cmbFont.Text = T_Properties.C_Font
        aFont = New Font(T_Properties.C_Font, 18, FontStyle.Bold)
        If T_Properties.C_Mode = 0 Then
            rbtn12Hour.Checked = True
        Else
            rbtn24Hour.Checked = True
        End If

        SetClockProperties()
    End Sub

    Private Sub btnCancel_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnCancel.Click

        ' Return a Cancel result - do NOT save the temporary settings
        Me.DialogResult = Windows.Forms.DialogResult.Cancel
        Me.Close()

    End Sub

    Private Sub btnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSave.Click

        DoSaveSettings()

        ' Return an OK result
        Me.DialogResult = Windows.Forms.DialogResult.OK
        Me.Close()

    End Sub

    Private Sub FormDClockPrefs_Activated(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Activated

        If amActive Then Exit Sub
        amActive = True

        ' Get a working copy of the current settings
        T_Properties = C_Properties

        ' Set up the screen widgets
        SetupScreen()

        TimerPrefs.Enabled = True

        PostTime()

    End Sub

    Private Sub TimerPrefs_Tick(ByVal sender As Object, ByVal e As System.EventArgs) Handles TimerPrefs.Tick
        iTicks = iTicks + 1
        If iTicks >= 5 Then PostTime()
    End Sub

    Private Sub txtColorBlack_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtColorBlack.Click
        T_Properties.C_ForeColor = txtColorBlack.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtColorGreen_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtColorGreen.Click
        T_Properties.C_ForeColor = txtColorGreen.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtColorTeal_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtColorTeal.Click
        T_Properties.C_ForeColor = txtColorTeal.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtColorRed_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtColorRed.Click
        T_Properties.C_ForeColor = txtColorRed.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtColorWhite_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtColorWhite.Click
        T_Properties.C_ForeColor = txtColorWhite.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtColorYellow_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtColorYellow.Click
        T_Properties.C_ForeColor = txtColorYellow.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtBGColorBlack_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtBGColorBlack.Click
        T_Properties.C_Backcolor = txtBGColorBlack.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtBGColorDkRed_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtBGColorDkRed.Click
        T_Properties.C_Backcolor = txtBGColorDkRed.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtBGColorDkGreen_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtBGColorDkGreen.Click
        T_Properties.C_Backcolor = txtBGColorDkGreen.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtBGColorGrey_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtBGColorGrey.Click
        T_Properties.C_Backcolor = txtBGColorGrey.BackColor
        SetClockProperties()
    End Sub

    Private Sub txtBGColorWhite_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles txtBGColorWhite.Click
        T_Properties.C_Backcolor = txtBGColorWhite.BackColor
        SetClockProperties()
    End Sub

    Private Sub rbtn12Hour_CheckedChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles rbtn12Hour.CheckedChanged
        If rbtn12Hour.Checked Then
            T_Properties.C_Mode = 0
        End If
        SetClockProperties()
    End Sub

    Private Sub rbtn24Hour_CheckedChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles rbtn24Hour.CheckedChanged
        If rbtn24Hour.Checked Then
            T_Properties.C_Mode = 1
        End If
        SetClockProperties()
    End Sub

    Private Sub chkSeconds_CheckedChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles chkSeconds.CheckedChanged
        T_Properties.C_Seconds = chkSeconds.Checked
        SetClockProperties()
    End Sub

    Private Sub cmbFont_SelectedIndexChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles cmbFont.SelectedIndexChanged
        Dim i As Integer
        i = cmbFont.SelectedIndex
        If i = -1 Then Exit Sub

        T_Properties.C_Font = cmbFont.Text
        Try
            aFont.Dispose()
            aFont = New Font(T_Properties.C_Font, 18, FontStyle.Bold)
        Catch ex As Exception
        End Try

        SetClockProperties()

    End Sub

End Class